@@ -1,4 +1,4 @@
-version_info = (2, 0, 11)
+version_info = (2, 1, 0)
 
 __version__ = version = '.'.join(map(str, version_info))
 __project__ = PROJECT = __name__
@@ -6,7 +6,7 @@ __author__ = AUTHOR = "Kirill Klenov <horneds@gmail.com>"
 __license__ = LICENSE = "GNU LGPL"
 
 try:
-    from django.conf import settings as django_settings
+    from django.conf import settings as django_settings # nolint
     if not 'adrest' in django_settings.INSTALLED_APPS:
         import logging
         logging.warn('You should add "adrest" to INSTALLED_APPS.')
