@@ -11,64 +11,69 @@ __all__ = 'EmitterMixin',
 
 
 class EmitterMeta(type):
-
+    """ Prepare resource's emiters.
+    """
     def __new__(mcs, name, bases, params):
-
         params['meta'] = params.get('meta', MetaOptions())
         cls = super(EmitterMeta, mcs).__new__(mcs, name, bases, params)
+
         cls.emitters = as_tuple(cls.emitters)
-        cache = set()
-        cls.meta.default_emitter = cls.emitters[0] if cls.emitters else None
+        assert cls.emitters, "Resource should have emitters."
+        cls.meta.emitters_dict = dict(
+            (e.media_type, e) for e in cls.emitters
+        )
+
         for e in cls.emitters:
-            assert issubclass(e, BaseEmitter), "Emitter must be subclass of BaseEmitter"
+            assert issubclass(e, BaseEmitter), \
+                "Emitter should be subclass of `adrest.utils.emitter.BaseEmitter`" # nolint
 
-            # Skip dublicates
-            if e in cache:
-                continue
-            cache.add(e)
-
-            cls.meta.emitters_dict[e.media_type] = e
-            cls.meta.emitters_types.append(e.media_type)
         return cls
 
 
 class EmitterMixin(object):
     """ Serialize response.
 
-        :param emitters: Emitter's class (list of classes), choosen by http header
-        :param template: Force template name for template based emitters
+        :param emitters: Emitter's choosen by http header
+        :param emit_template: Force template name for template based emitters
         :param emit_fields: Manualy defined set of model fields for serializers
-        :param emit_include: Additionaly included fields for model serialization
+        :param emit_include: Additionaly fields for model serialization
         :param emit_exclude: Exclude fields from model serialization
         :param emit_related: Dict with field serialization options
 
         Example: ::
 
             class SomeResource():
-                emit_fields = ['pk', 'user']
+                emit_fields = ['pk', 'user', 'customfield']
                 emit_related = {
                     'user': {
                         _fields: ['username']
                     }
                 }
 
-    """
+                def dehydrate__customfield(self, user):
+                    return "I'm hero! " + user.username
 
+    """
     __metaclass__ = EmitterMeta
 
     emitters = JSONEmitter
-    template = None
+    emit_template = None
+    emit_fields = None
+    emit_related = None
+    emit_include = None
+    emit_exclude = None
 
     def emit(self, content, request=None, emitter=None):
-        " Serialize reponse "
-
+        """ Serialize response.
+        """
         # Get emitter for request
-        emitter = emitter or self._determine_emitter(request)
+        emitter = emitter or self.determine_emitter(request)
         emitter = emitter(self, request=request, response=content)
 
         # Serialize the response content
         response = emitter.emit()
-        assert isinstance(response, HttpResponse), "Emitter must return HttpResponse"
+        assert isinstance(response, HttpResponse), \
+            "Emitter must return HttpResponse"
 
         # Append pagination headers
         if isinstance(content, Paginator):
@@ -76,22 +81,34 @@ class EmitterMixin(object):
             if content.next:
                 linked_resources.append('<%s>; rel="next"' % content.next)
             if content.previous:
-                linked_resources.append('<%s>; rel="previous"' % content.previous)
+                linked_resources.append(
+                    '<%s>; rel="previous"' % content.previous)
             response["Link"] = ", ".join(linked_resources)
 
         return response
 
-    def _determine_emitter(self, request):
+    @staticmethod
+    def to_simple(content, simple):
+        """ Modify simple structure before response.
+        """
+        return simple
+
+    @classmethod
+    def determine_emitter(cls, request):
         " Return must fine emitter for request "
+        default_emitter = cls.emitters[0]
         if not request:
-            return self.meta.default_emitter
+            return default_emitter
 
         if request.method == 'OPTIONS':
             return JSONEmitter
 
         accept = request.META.get('HTTP_ACCEPT', '*/*')
         if accept == '*/*':
-            return self.meta.default_emitter
+            return default_emitter
 
-        base_format = mimeparse.best_match(self.meta.emitters_types, accept)
-        return self.meta.emitters_dict.get(base_format, self.meta.default_emitter)
+        base_format = mimeparse.best_match(cls.meta.emitters_dict.keys(),
+                                           accept)
+        return cls.meta.emitters_dict.get(
+            base_format,
+            default_emitter)
