@@ -1,8 +1,8 @@
 from django.db import models
 from django.utils.encoding import smart_unicode
 
-from adrest import settings
-from adrest.signals import api_request_finished
+from . import settings
+from .signals import api_request_finished
 
 
 # Preloads ADREST tags
@@ -43,7 +43,8 @@ if settings.ACCESS_LOG:
             verbose_name_plural = "Access"
 
         def __unicode__(self):
-            return "#%s %s:%s:%s" % (self.pk, self.method, self.status_code, self.uri)
+            return "#{0} {1}:{2}:{3}".format(
+                self.pk, self.method, self.status_code, self.uri)
 
     def save_log(sender, response=None, request=None, **resources):
 
@@ -56,7 +57,8 @@ if settings.ACCESS_LOG:
             content = smart_unicode(response.content)[:5000]
         except (UnicodeDecodeError, UnicodeEncodeError):
             if response and response['Content-Type'].lower() not in \
-                    [emitter.media_type.lower() for emitter in resource.emitters]:
+                    [emitter.media_type.lower()
+                        for emitter in resource.emitters]:
                 content = 'Invalid response content encoding'
             else:
                 content = response.content[:5000]
@@ -66,8 +68,10 @@ if settings.ACCESS_LOG:
             method=request.method,
             version=str(resource.api),
             status_code=response.status_code,
-            request='%s\n\n%s' % (str(request.META), str(getattr(request, 'data', ''))),
-            identifier=resource.identifier or request.META.get('REMOTE_ADDR', 'anonymous'),
+            request='%s\n\n%s' % (str(request.META), str(
+                getattr(request, 'data', ''))),
+            identifier=resource.identifier or request.META.get(
+                'REMOTE_ADDR', 'anonymous'),
             response=content)
 
     api_request_finished.connect(save_log)
